Mixed Up Code - Free Response Practice
:::::::::::::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   RandomStringChooserParsonsA.rst
   RandomStringChooserA2.rst
   RandomStringChooserParsonsB.rst
   RandomStringChooserB2.rst
   Exercises.rst

